@@ -22,6 +22,14 @@ GType gdl_dock_placement_get_type (void);
 GType gdl_dock_item_behavior_get_type (void);
 #define GDL_TYPE_DOCK_ITEM_FLAGS gdl_dock_item_flags_get_type()
 GType gdl_dock_item_flags_get_type (void);
+
+/* --- gdl-dock-bar.h --- */
+#define GDL_TYPE_DOCK_BAR_STYLE gdl_dock_bar_style_get_type()
+GType gdl_dock_bar_style_get_type (void);
+
+/* --- gdl-switcher.h --- */
+#define GDL_TYPE_SWITCHER_STYLE gdl_switcher_style_get_type()
+GType gdl_switcher_style_get_type (void);
 G_END_DECLS
 
 #endif /* __LIBGDLTYPEBUILTINS_H__ */
